##################################################
# Events

evNothing          = 0
evCommand          = 1
evInformation      = 2
evExpose           = 3

evKeyPress         = 5
evKeyRelease       = 6
evKeyRepeat        = 7
evPtrRelative      = 8
evPtrAbsolute      = 9
evPtrButtonPress   = 10
evPtrButtonRelease = 11
evValRelative      = 12
evValAbsolute      = 13

evLast             = 14     # not normaly used

##################################################
# Event masks

emNothing          = 1 << evNothing

emCommand          = 1 << evCommand
emInformation      = 1 << evInformation
emExpose           = 1 << evExpose

emKeyPress         = 1 << evKeyPress
emKeyRelease       = 1 << evKeyRelease
emKeyRepeat        = 1 << evKeyRepeat
emKey	           = emKeyPress | emKeyRelease | emKeyRepeat
emKeyboard         = emKey

emPtrRelative      = 1 << evPtrRelative
emPtrAbsolute      = 1 << evPtrAbsolute
emPtrButtonPress   = 1 << evPtrButtonPress
emPtrButtonRelease = 1 << evPtrButtonRelease
emPtrMove	   = emPtrRelative | emPtrAbsolute
emPtrButton	   = emPtrButtonPress | emPtrButtonRelease
emPointer	   = emPtrMove | emPtrButton

emValRelative      = 1 << evValRelative
emValAbsolute      = 1 << evValAbsolute
emValuator	   = emValRelative | emValAbsolute

emZero             = 0

emAll	           = ( (1 << evLast) - 1 ) & ~emNothing

##################################################
# Physics type (for valuators)

ptUnknown         = 0
ptTime            = 1   # base unit s 
ptFrequency       = 2	# base unit 1/s (Hz) 
ptLength          = 3 	# base unit m 
ptVelocity        = 4 	# base unit m/s 
ptAcceleration    = 5 	# base unit m/s^2 
ptAngle           = 6	# base unit radian 
ptAngVelocity     = 7	# base unit radian/s 
ptAngAcceleration = 8	# base unit radian/s^2 
ptArea            = 9 	# base unit m^2 
ptVolume          = 10	# base unit m^3 
ptMass            = 11	# base unit kg 
ptForce           = 12 	# base unit N (kg*m/s^2) 
ptPressure        = 13 	# base unit N/m^2 (Pa) 
ptTorque          = 14	# base unit Nm 
ptEnergy          = 15	# base unit Nm, VAs, J 
ptPower           = 16	# base unit Nm/s, VA, W 
ptTemperature     = 17	# base unit K 
ptCurrent         = 18	# base unit A 
ptVoltage         = 19	# base unit V (kg*m^2/(As^3)) 
ptResistance      = 20 	# base unit V/A (Ohm) 
ptCapacity        = 21 	# base unit As/V (Farad) 
ptInductivity     = 22 	# base unit Vs/A (Henry)

ptLast            = 23


##################################################
# Command event specific

# event.any.origin values
originNone      = 0x00000000
originSendEvent = ~0x7fffffff # 0x80000000

# event.any.target values
targetAll       = 0x00000000
targetQueue     = ~0x7fffffff  # 0x80000000

# event.cmd.code flags
cmdflagNoData   = ~0x7fffffff
cmdflagPrivate  = 1 << 30
cmdflagExternal = 1 << 29
cmdflagGGI      = cmdflagExternal >> 1 # GGI specific event

# event.cmd.code 
cmdEventLost    = 0x01 | cmdflagNoData
cmdPreferAbsPtr = 0x02 | cmdflagNoData
cmdPreferRelPtr = 0x03 | cmdflagNoData
cmdGetDevInfo   = 0x01
cmdGetValInfo   = 0x02

# GGI 
cmdNoHaltOnUnMap     = cmdflagGGI | cmdflagExternal | cmdflagNoData | 0x01
cmdHaltOnUnMap       = cmdflagGGI | cmdflagExternal | cmdflagNoData | 0x02
cmdRequestSwitch     = cmdflagGGI | cmdflagExternal                 | 0x01
cmdAcknowledgeSwitch = cmdflagGGI | cmdflagExternal | cmdflagNoData | 0x03

# XXX cmd data switch request specific values?


valQueryAll     = ~0   # 0xffffffff

##################################################
# Device info specific
numMax     = ~0x010000 # 0xfffeffff
numUnknown = ~0        # 0xffffffff

##################################################
# Pointer event specific

pbuttonLeft   = 1
pbuttonRight  = 2
pbuttonMiddle = 3

##################################################
# Famous GGI flags

flagAsync      = 0x0001
flagTidyBuf    = 0x0002

