#################################################
# Flags
#################################################

#############################################
# Face().face_flags
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_FACE_FLAG_XXX
FACE_SCALABLE         = 1
FACE_FIXED_SIZES      = 2
FACE_FIXED_WIDTH      = 4
FACE_SFNT             = 8
FACE_HORIZONTAL       = 0x10
FACE_VERTICAL         = 0x20
FACE_KERNING          = 0x40
FACE_FAST_GLYPHS      = 0x80
FACE_MULTIPLE_MASTERS = 0x100
FACE_GLYPH_NAMES      = 0x200
FACE_EXTERNAL_STREAM  = 0x4000

faceProperties = {
    FACE_SCALABLE         : 'scalable',
    FACE_FIXED_SIZES      : 'fixed sizes',
    FACE_FIXED_WIDTH      : 'fixed width',
    FACE_SFNT             : 'sfnt',
    FACE_HORIZONTAL       : 'horizontal',
    FACE_VERTICAL         : 'vertical',
    FACE_KERNING          : 'kerning',
    FACE_FAST_GLYPHS      : 'fast glyphs',
    FACE_MULTIPLE_MASTERS : 'multiple masters',
    FACE_GLYPH_NAMES      : 'glyph names',
    FACE_EXTERNAL_STREAM  : 'external streams'
    }

#############################################
# Face().style_flags
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_STYLE_FLAG_XXX
STYLE_ITALIC = 1
STYLE_BOLD   = 2

#############################################
# Face().charmaps[*].[0] (=encoding)
# Face().encoding = ...
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_Encoding
def _mk_enc(s):
    return (ord(s[0]) << 24) | (ord(s[1]) << 16) | (ord(s[2]) << 8) | ord(s[3])
ENCODING_NONE           = 0
ENCODING_MS_SYMBOL      = _mk_enc('symb')
ENCODING_UNICODE        = _mk_enc('unic')
ENCODING_OLD_LATIN_2    = _mk_enc('lat2')
ENCODING_SJIS           = _mk_enc('sjis')
ENCODING_GB2312         = _mk_enc('gb  ')
ENCODING_BIG5           = _mk_enc('big5')
ENCODING_WANSUNG        = _mk_enc('wans')
ENCODING_JOHAB          = _mk_enc('joha')
ENCODING_ADOBE_LATIN_1  = _mk_enc('lat1')
ENCODING_ADOBE_STANDARD = _mk_enc('ADOB')
ENCODING_ADOBE_EXPERT   = _mk_enc('ADBE')
ENCODING_ADOBE_CUSTOM   = _mk_enc('ADBC')
ENCODING_APPLE_ROMAN    = _mk_enc('armn')

faceCharmaps = {
    ENCODING_NONE           : 'none',
    ENCODING_MS_SYMBOL      : 'symbol',
    ENCODING_UNICODE        : 'unicode',
    ENCODING_OLD_LATIN_2    : 'latin2',
    ENCODING_SJIS           : 'shift-jis',
    ENCODING_GB2312         : 'gb2312',
    ENCODING_BIG5           : 'big5',
    ENCODING_WANSUNG        : 'wansung',
    ENCODING_JOHAB          : 'johab',
    ENCODING_ADOBE_STANDARD : 'adobe-latin-1',
    ENCODING_ADOBE_STANDARD : 'adobe-standard',
    ENCODING_ADOBE_EXPERT   : 'adobe-expert',
    ENCODING_ADOBE_CUSTOM   : 'adobe-custom',
    ENCODING_APPLE_ROMAN    : 'apple-roman',
    }


##############################################
# Face.load_glyph(i, ... = LOAD_DEFAULT)
# Face.load_char(i, ... = LOAD_DEFAULT)
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_LOAD_XXX
LOAD_DEFAULT                     =     0
LOAD_NO_SCALE                    =     1
LOAD_NO_HINTING                  =     2
LOAD_RENDER                      =     4
LOAD_NO_BITMAP                   =     8
LOAD_VERTICAL_LAYOUT             =    16
LOAD_FORCE_AUTOHINT              =    32
LOAD_CROP_BITMAP                 =    64
LOAD_PEDANTIC                    =   128
LOAD_IGNORE_GLOBAL_ADVANCE_WIDTH =   512
LOAD_NO_RECURSE                  =  1024
LOAD_IGNORE_TRANSFORM            =  2048
LOAD_MONOCHROME                  =  4096
LOAD_LINEAR_DESIGN               =  8192
LOAD_SBITS_ONLY                  = 16384

#######################################################
# Face().get_kerning(left, right, ... = KERNING_DEFAULT)
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_Kerning_Mode
KERNING_DEFAULT  = 0
KERNING_UNFITTED = 1
KERNING_UNSCALED = 2


#######################################################
# Face().render_glyph(mode = 0) and Glyph().to_bimap()
# http://www.freetype.org/freetype2/docs/reference/ft2-base_interface.html#FT_Render_Mode
RENDER_MODE_NORMAL     = 0
RENDER_MODE_LIGHT      = 1
RENDER_MODE_MONO       = 2
RENDER_MODE_LCD        = 3
RENDER_MODE_LCD_V      = 4

# Glyph format in Glyph().format and Face().glyph_format
# http://www.freetype.org/freetype2/docs/reference/ft2-basic_types.html#FT_Glyph_Format
GLYPH_NONE      = 0
GLYPH_COMPOSITE = _mk_enc('comp')
GLYPH_BITMAP    = _mk_enc('bits')
GLYPH_OUTLINE   = _mk_enc('outl')
GLYPH_PLOTTER   = _mk_enc('plot')

# Glyph bbox for Glyph.to_bitmap()
# http://www.freetype.org/freetype2/docs/reference/ft2-glyph_management.html#FT_Glyph_BBox_Mode
GLYPH_BBOX_UNSCALED  = 0
GLYPH_BBOX_SUBPIXELS = 0
GLYPH_BBOX_GRIDFIT   = 1
GLYPH_BBOX_TRUNCATE  = 2
GLYPH_BBOX_PIXELS    = 3

from _ft2module import Library

def getFaceProperties(f):
    a=f.faceFlags
    return [ faceProperties[i] for i in faceProperties.keys() if a & i ]

def getFaceEncodings(f):
    return [ faceCharmaps[i[0]] for i in f.charmaps ]
